# instadp
> Download any users Instagram display picture/profile picture in full quality

[![asciicast](https://asciinema.org/a/210125.svg)](https://asciinema.org/a/210125)

## Installation
### Pip installation

```pip install instadp```

### Git installation
```bash
# clone the repo
$ git clone https://github.com/sdushantha/instadp.git

# change the working directory to instadp
$ cd instadp

# install the requirements
$ pip3 install -r requirements.txt
```

## Usage
```
usage: instadp.py [-h] username
```
